@@ -957,9 +957,11 @@ build_server_tree (SmbVirtualFile **out, const char *name)
 				error = cli_error(connection->cli, NULL, NULL, NULL);
 				if (error == EACCES) {
 					memset (&out_args, 0, sizeof (out_args));
+					UNLOCK_SAMBA();
 					res = gnome_vfs_module_callback_invoke (GNOME_VFS_MODULE_CALLBACK_AUTHENTICATION,
 										&in_args, sizeof (in_args), 
 										&out_args, sizeof (out_args));
+					LOCK_SAMBA();
 					if (!res || (out_args.username == NULL)) {
 						break;
 					} else {
@@ -1171,9 +1173,11 @@ lookup_uri (GnomeVFSURI     *uri,
 								 &(*file)->u.share.connection);
 				if (res == GNOME_VFS_ERROR_LOGIN_FAILED) {
 					memset (&out_args, 0, sizeof (out_args));
+					UNLOCK_SAMBA();
 					res = gnome_vfs_module_callback_invoke (GNOME_VFS_MODULE_CALLBACK_AUTHENTICATION,
 										&in_args, sizeof (in_args), 
 										&out_args, sizeof (out_args));
+					LOCK_SAMBA();
 					if (!res) {
 						break;
 					} else if (out_args.username == NULL) {
